
### This script creates an R function to generate raincloud plots, then simulates
### data for plots. If using for your own data, you only need lines 1-80.
### It relies largely on code previously written by David Robinson
### (https://gist.github.com/dgrtwo/eb7750e74997891d7c20)
### and the package ggplot2 by Hadley Wickham

# Check if required packages are installed ----
packages <- c("cowplot", "readr", "ggplot2", "dplyr", "lavaan", "smooth", "Hmisc")
if (length(setdiff(packages, rownames(installed.packages()))) > 0) {
  install.packages(setdiff(packages, rownames(installed.packages())))
}

# Load packages ----
library(ggplot2)

# Defining the geom_flat_violin function ----
# Note: the below code modifies the
# existing github page by removing a parenthesis in line 50

"%||%" <- function(a, b) {
  if (!is.null(a)) a else b
}

geom_flat_violin <- function(mapping = NULL, data = NULL, stat = "ydensity",
                             position = "dodge", trim = TRUE, scale = "area",
                             show.legend = NA, inherit.aes = TRUE, ...) {
  layer(
    data = data,
    mapping = mapping,
    stat = stat,
    geom = GeomFlatViolin,
    position = position,
    show.legend = show.legend,
    inherit.aes = inherit.aes,
    params = list(
      trim = trim,
      scale = scale,
      ...
    )
  )
}

#' @rdname ggplot2-ggproto
#' @format NULL
#' @usage NULL
#' @export
GeomFlatViolin <-
  ggproto("GeomFlatViolin", Geom,
          setup_data = function(data, params) {
            data$width <- data$width %||%
              params$width %||% (resolution(data$x, FALSE) * 0.9)
            
            # ymin, ymax, xmin, and xmax define the bounding rectangle for each group
            data %>%
              group_by(group) %>%
              mutate(
                ymin = min(y),
                ymax = max(y),
                xmin = x,
                xmax = x + width / 2
              )
          },
          
          draw_group = function(data, panel_scales, coord) {
            # Find the points for the line to go all the way around
            data <- transform(data,
                              xminv = x,
                              xmaxv = x + violinwidth * (xmax - x)
            )
            
            # Make sure it's sorted properly to draw the outline
            newdata <- rbind(
              plyr::arrange(transform(data, x = xminv), y),
              plyr::arrange(transform(data, x = xmaxv), -y)
            )
            
            # Close the polygon: set first and last point the same
            # Needed for coord_polar and such
            newdata <- rbind(newdata, newdata[1, ])
            ggplot2:::ggname("geom_flat_violin", GeomPolygon$draw_panel(newdata, panel_scales, coord))
          },
          
          draw_key = draw_key_polygon,
          
          default_aes = aes(
            weight = 1, colour = "grey20", fill = "white", size = 0.5,
            alpha = NA, linetype = "solid"
          ),
          
          required_aes = c("x", "y")
  )
        


# summarySE <- function(data = NULL, measurevar, groupvars = NULL, na.rm = FALSE,
#                       conf.interval = .95, .drop = TRUE) {
#   library(plyr)
#   
#   # New version of length which can handle NA's: if na.rm==T, don't count them
#   length2 <- function(x, na.rm = FALSE) {
#     if (na.rm) {
#       sum(!is.na(x))
#     } else {
#       length(x)
#     }
#   }
#   
#   # This does the summary. For each group's data frame, return a vector with
#   # N, mean, median, and sd
#   
#   datac <- plyr::ddply(data, groupvars, .drop=.drop,
#                        .fun = function(xx, col) {
#                          c(N      = length2(xx[[col]], na.rm=na.rm),
#                            mean   = mean(xx[[col]], na.rm=na.rm),
#                            median = median(xx[[col]], na.rm=na.rm),
#                            sd      = sd(xx[[col]], na.rm=na.rm)
#                          )
#                        },
#                        measurevar
#   )
#   
#   # Rename the "mean" and "median" columns    
#   datac <- plyr::rename(datac, c("mean" = paste(measurevar, "_mean", sep = "")))
#   datac <- plyr::rename(datac, c("median" = paste(measurevar, "_median", sep = "")))
#   
#   datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean
#   
#   # Confidence interval multiplier for standard error
#   # Calculate t-statistic for confidence interval:
#   # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
#   ciMult <- qt(conf.interval / 2 + .5, datac$N - 1)
#   datac$ci <- datac$se * ciMult
#   
#   return(datac)
# }
# 
# 

###########################  ACCURATEZZA

library(extrafont)

#font_import()
loadfonts(device="win")       #Register fonts for Windows bitmap output
fonts()   

data_accuracy<-read.csv(file.choose(),sep = ";",dec = ",",header = T)
resp_data<-data_accuracy

resp_data$Block<-factor(resp_data$Block, levels = c("SB", "U", "LB"))
resp_data$Soa<-factor(resp_data$Soa,levels = c("Short", "Medium", "Long"))

p10 <- ggplot(resp_data, aes(x = Soa, y = Accuracy, fill = Block)) +
  geom_flat_violin(aes(fill = Block),position = position_nudge(x = .2, y = 0), adjust = 1, trim = T, alpha = .5, colour = NA)+
  geom_point(aes(x = as.numeric(Soa), y = Accuracy, colour = Block),position = position_jitter(width = .1), size = 1.5, shape = 20)+
  geom_boxplot(aes(x = Soa, y = Accuracy, fill = Block),outlier.shape = NA, alpha = .4, width = .3, colour = "black")+
  scale_colour_brewer(palette = "Dark2")+
  scale_fill_brewer(palette = "Dark2")+
  ylab("% of correct responses")+
  
  
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),panel.background = element_blank())+
  theme(axis.line = element_line(colour = 'black', size = 0.5))+
  theme(text=element_text(family="Times New Roman", face="bold", size=24))+coord_cartesian(ylim = c(90,100))
#ggsave('10repanvplot.tiff', width = w, height = h, dpi=600)# SALVA A 600 DPI!!!!!
#coord_flip()
p10

ggsave("Acc_SoaXBlock_font24.tiff", width=14.3, height = 7.76, dpi=600)# SALVA A 600 DPI!!!!!


interaction_acc<-as.data.frame(effect("Soa*Block",model_accuracy))
interaction_acc$Block<-factor(interaction_acc$Block, levels = c("SB", "U", "LB"))
interaction_acc$Soa<-factor(interaction_acc$Soa,levels = c("Short", "Medium", "Long"))


p11 <- ggplot(resp_data, aes(x = Soa, y = Accuracy, fill = Block)) +
  geom_flat_violin(aes(fill = Block),position = position_nudge(x = .3, y = 0), adjust = 1, trim = T, alpha = .5, colour = NA)+
  geom_point(aes(x = as.numeric(Soa), y = Accuracy, colour = Block),position = position_jitter(width = .1), size = 1.5, shape = 20)+
  geom_boxplot(aes(x = Soa, y = Accuracy, fill = Block),outlier.shape = NA, alpha = .4, width = .3, colour = "black")+
  scale_colour_brewer(palette = "Dark2")+
  scale_fill_brewer(palette = "Dark2")+
  ylab("% of correct responses")+
  
  geom_line(data = interaction_acc, aes(x = as.numeric(Soa)+.22, y = fit, group = Block, colour = Block), linetype = 1,position = position_dodge(.1))+
  geom_point(data = interaction_acc, aes(x = as.numeric(Soa)+.22, y = fit, group = Block, colour = Block), shape = 18,position = position_dodge(.1)) +
  geom_errorbar(data = interaction_acc, aes(x = as.numeric(Soa)+.22, y = fit, group = Block, colour = Block, ymin = fit-se, ymax = fit+se), 
                width = .05,position = position_dodge(.1))+
  
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),panel.background = element_blank())+
  theme(axis.line = element_line(colour = 'black', size = 0.5))+
  theme(text=element_text(family="Times New Roman", face="bold", size=24))+coord_cartesian(ylim = c(90,100))
#ggsave('10repanvplot.tiff', width = w, height = h, dpi=600)# SALVA A 600 DPI!!!!!
#coord_flip()
p11

ggsave("p09.tiff", width=14.3, height = 7.76, dpi=600)# SALVA A 600 DPI!!!!!


###############################   TEMPI DI REAZIONE


resp_data<-data_RT

# sumrepdat<-summarySE(resp_data,measurevar = "Accuracy",
#                      groupvars = c("Soa","Block"))
# 
# 
# head(sumrepdat)

resp_data$Block<-factor(resp_data$Block, levels = c("SB", "U", "LB"))
resp_data$Soa<-factor(resp_data$Soa,levels = c("Short", "Medium", "Long"))

p10 <- ggplot(resp_data, aes(x = Soa, y = Reaction_times, fill = Block)) +
  geom_flat_violin(aes(fill = Block),position = position_nudge(x = .2, y = 0), adjust = 1, trim = F, alpha = .5, colour = NA)+
  geom_point(aes(x = as.numeric(Soa), y = Reaction_times, colour = Block),position = position_jitter(width = .1), size = 1.5, shape = 20)+
  geom_boxplot(aes(x = Soa, y = Reaction_times, fill = Block),outlier.shape = NA, alpha = .4, width = .3, colour = "black")+
  scale_colour_brewer(palette = "Dark2")+
  scale_fill_brewer(palette = "Dark2")+
  ylab("RTs")+
  
  
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),panel.background = element_blank())+
  theme(axis.line = element_line(colour = 'black', size = 0.5))+
  theme(text=element_text(family="Times New Roman", face="bold", size=24))#+coord_cartesian(ylim = c(90,103))
#ggsave('10repanvplot.tiff', width = w, height = h, dpi=600)# SALVA A 600 DPI!!!!!
#coord_flip()
p10

ggsave("RT_SoaXBlock_font24.tiff", width=14.3, height = 7.76, dpi=600)# SALVA A 600 DPI!!!!!


interaction_RT<-as.data.frame(effect("Soa*Block",model_RT))
interaction_RT$Block<-factor(interaction_RT$Block, levels = c("SB", "U", "LB"))
interaction_RT$Soa<-factor(interaction_RT$Soa,levels = c("Short", "Medium", "Long"))


p11 <- ggplot(resp_data, aes(x = Soa, y = Reaction_times, fill = Block)) +
  geom_flat_violin(aes(fill = Block),position = position_nudge(x = .3, y = 0), adjust = 1, trim = F, alpha = .5, colour = NA)+
  geom_point(aes(x = as.numeric(Soa), y = Reaction_times, colour = Block),position = position_jitter(width = .1), size = 1.5, shape = 20)+
  geom_boxplot(aes(x = Soa, y = Reaction_times, fill = Block),outlier.shape = NA, alpha = .4, width = .3, colour = "black")+
  scale_colour_brewer(palette = "Dark2")+
  scale_fill_brewer(palette = "Dark2")+
  ylab("RTs")+
  
  geom_line(data = interaction_RT, aes(x = as.numeric(Soa)+.22, y = fit, group = Block, colour = Block), linetype = 1,position = position_dodge(.1))+
  geom_point(data = interaction_RT, aes(x = as.numeric(Soa)+.22, y = fit, group = Block, colour = Block), shape = 18,position = position_dodge(.1)) +
  geom_errorbar(data = interaction_RT, aes(x = as.numeric(Soa)+.22, y = fit, group = Block, colour = Block, ymin = fit-se, ymax = fit+se), 
                   width = .05,position = position_dodge(.1))+
  
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),panel.background = element_blank())+
  theme(axis.line = element_line(colour = 'black', size = 0.5))+
  theme(text=element_text(family="Times New Roman", face="bold", size=24))#+coord_cartesian(ylim = c(90,103))
#ggsave('10repanvplot.tiff', width = w, height = h, dpi=600)# SALVA A 600 DPI!!!!!
#coord_flip()
p11

ggsave("p11.tiff", width=14.3, height = 7.76, dpi=600)# SALVA A 600 DPI!!!!!

library(ggplot2)

df<-read.csv(file.choose(),sep = ";",dec = ",",header = T)
df$ID<-rep(paste0("S",1:48),6)


ei_sbs<-mean(df[1:48,3])
ei_lbs<-mean(df[49:96,3])

ri_sbs<-mean(df[97:144,3])
ri_lbs<-mean(df[145:192,3])

ev_sbs<-mean(df[193:240,3])
ev_lbs<-mean(df[241:288,3])

df_ei<-subset(df, Condizione == "Expectancy Implementation")
df_ei$Contrasto<-relevel(df_ei$Contrasto,ref = "SB-S")


prova<-data.frame(Contrasto="SB-S",mV=ei_sbs,ID="M")
prova2<-data.frame(Contrasto="LB-S",mV=ei_lbs,ID="M")
seg1<-data.frame(y1=ei_sbs,y2=ei_lbs,x1="SB-S",x2="LB-S",ID="M")


a<-ggplot(df_ei, aes(x = Contrasto, y = mV, group=ID,col=ID)) +
  geom_line(colour="grey")+geom_point(shape=21,size=2,colour="black",fill="white")+coord_cartesian(ylim = c(-31,58))+
  geom_segment(aes(x = x1, y = y1, xend = x2, yend = y2, colour = "red"),
               lwd=1.5,data = seg1,show.legend = F)+
  geom_point(data = prova,aes(x=Contrasto,y=mV),col="red",size=3.5)+
  geom_point(data = prova2,aes(x=Contrasto,y=mV),col="red",size=3.5)+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),panel.background = element_blank())+
  ylab(expression(mu*"V"))+xlab("Blocks")+
  ggtitle("Expectancy Implementation")+
  theme(plot.title = element_text(hjust = 0.5))+
  theme(axis.line = element_line(colour = 'black', size = 0.5))+
  theme(text=element_text(family="Times New Roman", face="bold", size=24))


df_ri<-subset(df, Condizione == "Response Implementation")
df_ri$Contrasto<-relevel(df_ri$Contrasto,ref = "SB-S")

prova3<-data.frame(Contrasto="SB-S",mV=ri_sbs,ID="M")
prova4<-data.frame(Contrasto="LB-S",mV=ri_lbs,ID="M")
seg2<-data.frame(y1=ri_sbs,y2=ri_lbs,x1="SB-S",x2="LB-S",ID="M")



b<-ggplot(df_ri, aes(x = Contrasto, y = mV, group=ID,col=ID)) +
  geom_line(colour="grey")+geom_point(shape=21,size=2,colour="black",fill="white")+coord_cartesian(ylim = c(-31,58))+
  geom_segment(aes(x = x1, y = y1, xend = x2, yend = y2, colour = "red"),
               lwd=1.5,data = seg2,show.legend = F)+
  geom_point(data = prova3,aes(x=Contrasto,y=mV),col="red",size=3.5)+
  geom_point(data = prova4,aes(x=Contrasto,y=mV),col="red",size=3.5)+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),panel.background = element_blank())+
  ylab(expression(mu*"V"))+xlab("Blocks")+
  ggtitle("Response Implementation")+
  theme(plot.title = element_text(hjust = 0.5))+
  theme(axis.line = element_line(colour = 'black', size = 0.5))+
  theme(text=element_text(family="Times New Roman", face="bold", size=24))


df_ev<-subset(df, Condizione == "Expectancy Violation")
df_ev$Contrasto<-relevel(df_ev$Contrasto,ref = "SB-L")

prova5<-data.frame(Contrasto="SB-L",mV=ev_sbs,ID="M")
prova6<-data.frame(Contrasto="LB-L",mV=ev_lbs,ID="M")
seg3<-data.frame(y1=ev_sbs,y2=ev_lbs,x1="SB-L",x2="LB-L",ID="M")



c<-ggplot(df_ev, aes(x = Contrasto, y = mV, group=ID,col=ID)) +
  geom_line(colour="grey")+geom_point(shape=21,size=2,colour="black",fill="white")+coord_cartesian(ylim = c(-31,58))+
  geom_segment(aes(x = x1, y = y1, xend = x2, yend = y2, colour = "red"),
               lwd=1.5,data = seg3,show.legend = F)+
  geom_point(data = prova5,aes(x=Contrasto,y=mV),col="red",size=3.5)+
  geom_point(data = prova6,aes(x=Contrasto,y=mV),col="red",size=3.5)+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),panel.background = element_blank())+
  ylab(expression(mu*"V"))+xlab("Blocks")+
  ggtitle("Expectancy Violation")+
  theme(plot.title = element_text(hjust = 0.5))+
  theme(axis.line = element_line(colour = 'black', size = 0.5))+
  theme(text=element_text(family="Times New Roman", face="bold", size=24))


library(gridExtra)

g <- arrangeGrob(a,c,b, ncol=3) 

ggsave("soggetti_correct_font24.tiff",g, width=17, height = 8, dpi=600)
